@@ -45,13 +45,13 @@ dodgr_contract_graph <- function (graph, verts = NULL) {
 
     hash <- get_hash (graph, hash = TRUE)
     hashc <- get_hash (graph, verts = verts, hash = FALSE)
-    fname_c <- file.path (tempdir (), paste0 ("dodgr_graphc_", hashc, ".Rds"))
+    fname_c <- fs::path (fs::path_temp (), paste0 ("dodgr_graphc_", hashc, ".Rds"))
 
-    if (file.exists (fname_c)) {
+    if (fs::file_exists (fname_c)) {
         graph_contracted <- list (graph = readRDS (fname_c))
     } else {
-        fname <- file.path (tempdir (), paste0 ("dodgr_graph_", hash, ".Rds"))
-        if (!file.exists (fname))
+        fname <- fs::path (fs::path_temp (), paste0 ("dodgr_graph_", hash, ".Rds"))
+        if (!fs::file_exists (fname))
             saveRDS (graph, fname)
 
         graph_contracted <- dodgr_contract_graph_internal (graph, v, verts)
@@ -64,12 +64,12 @@ dodgr_contract_graph <- function (graph, verts = NULL) {
 
         saveRDS (graph_contracted$graph, fname_c)
 
-        fname_e <- file.path (tempdir (),
-                              paste0 ("dodgr_edge_map_", hashc, ".Rds"))
+        fname_e <- fs::path (fs::path_temp (),
+                             paste0 ("dodgr_edge_map_", hashc, ".Rds"))
         saveRDS (graph_contracted$edge_map, fname_e)
 
-        fname_j <- file.path (tempdir (),
-                              paste0 ("dodgr_junctions_", hashc, ".Rds"))
+        fname_j <- fs::path (fs::path_temp (),
+                             paste0 ("dodgr_junctions_", hashc, ".Rds"))
         saveRDS (graph_contracted$junctions, fname_j)
     }
 
@@ -216,8 +216,8 @@ dodgr_uncontract_graph <- function (graph) {
               "have been changed")
 
     hash <- attr (graph, "hash")
-    fname <- file.path (tempdir (), paste0 ("dodgr_graph_", hash, ".Rds"))
-    if (!file.exists (fname))
+    fname <- fs::path (fs::path_temp (), paste0 ("dodgr_graph_", hash, ".Rds"))
+    if (!fs::file_exists (fname))
         stop (paste0 ("Graph must have been contracted in ",    # nocov
                       "current R session; and have retained ",  # nocov
                       "the same row structure"))                # nocov
@@ -234,9 +234,9 @@ dodgr_uncontract_graph <- function (graph) {
         # merging extra rows such as flow from compound junctions back into
         # "normal" (non-compound) edges
         hash <- get_hash (graph, hash = TRUE)
-        fname <- file.path (tempdir (), paste0 ("dodgr_edge_contractions_",
-                                                hash, ".Rds"))
-        if (!file.exists (fname))
+        fname <- fs::path (fs::path_temp (), paste0 ("dodgr_edge_contractions_",
+                                               hash, ".Rds"))
+        if (!fs::file_exists (fname))
             stop (paste0 ("Graph must have been contracted in ",    # nocov
                           "current R session; and have retained ",  # nocov
                           "the same row structure"))                # nocov
